@@ -15,9 +15,9 @@ use Doctrine\Common\Persistence\ManagerRegistry;
 use Doctrine\Common\Persistence\Mapping\ClassMetadata;
 use Doctrine\Common\Persistence\ObjectManager;
 use Symfony\Component\Validator\Constraint;
-use Symfony\Component\Validator\Exception\UnexpectedTypeException;
-use Symfony\Component\Validator\Exception\ConstraintDefinitionException;
 use Symfony\Component\Validator\ConstraintValidator;
+use Symfony\Component\Validator\Exception\ConstraintDefinitionException;
+use Symfony\Component\Validator\Exception\UnexpectedTypeException;
 
 /**
  * Unique Entity Validator checks if one or a set of fields contain unique values.
@@ -46,17 +46,17 @@ class UniqueEntityValidator extends ConstraintValidator
             throw new UnexpectedTypeException($constraint, __NAMESPACE__.'\UniqueEntity');
         }
 
-        if (!is_array($constraint->fields) && !is_string($constraint->fields)) {
+        if (!\is_array($constraint->fields) && !\is_string($constraint->fields)) {
             throw new UnexpectedTypeException($constraint->fields, 'array');
         }
 
-        if (null !== $constraint->errorPath && !is_string($constraint->errorPath)) {
+        if (null !== $constraint->errorPath && !\is_string($constraint->errorPath)) {
             throw new UnexpectedTypeException($constraint->errorPath, 'string or null');
         }
 
         $fields = (array) $constraint->fields;
 
-        if (0 === count($fields)) {
+        if (0 === \count($fields)) {
             throw new ConstraintDefinitionException('At least one field has to be specified.');
         }
 
@@ -71,14 +71,14 @@ class UniqueEntityValidator extends ConstraintValidator
                 throw new ConstraintDefinitionException(sprintf('Object manager "%s" does not exist.', $constraint->em));
             }
         } else {
-            $em = $this->registry->getManagerForClass(get_class($entity));
+            $em = $this->registry->getManagerForClass(\get_class($entity));
 
             if (!$em) {
-                throw new ConstraintDefinitionException(sprintf('Unable to find the object manager associated with an entity of class "%s".', get_class($entity)));
+                throw new ConstraintDefinitionException(sprintf('Unable to find the object manager associated with an entity of class "%s".', \get_class($entity)));
             }
         }
 
-        $class = $em->getClassMetadata(get_class($entity));
+        $class = $em->getClassMetadata(\get_class($entity));
         /* @var $class \Doctrine\Common\Persistence\Mapping\ClassMetadata */
 
         $criteria = array();
@@ -133,7 +133,7 @@ class UniqueEntityValidator extends ConstraintValidator
                 throw new ConstraintDefinitionException(sprintf('The "%s" entity repository does not support the "%s" entity. The entity should be an instance of or extend "%s".', $constraint->entityClass, $class->getName(), $supportedClass));
             }
         } else {
-            $repository = $em->getRepository(get_class($entity));
+            $repository = $em->getRepository(\get_class($entity));
         }
 
         $result = $repository->{$constraint->repositoryMethod}($criteria);
@@ -182,11 +182,11 @@ class UniqueEntityValidator extends ConstraintValidator
 
     private function formatWithIdentifiers(ObjectManager $em, ClassMetadata $class, $value)
     {
-        if (!is_object($value) || $value instanceof \DateTimeInterface) {
+        if (!\is_object($value) || $value instanceof \DateTimeInterface) {
             return $this->formatValue($value, self::PRETTY_DATE);
         }
 
-        if ($class->getName() !== $idClass = get_class($value)) {
+        if ($class->getName() !== $idClass = \get_class($value)) {
             // non unique value might be a composite PK that consists of other entity objects
             if ($em->getMetadataFactory()->hasMetadataFor($idClass)) {
                 $identifiers = $em->getClassMetadata($idClass)->getIdentifierValues($value);
@@ -204,10 +204,10 @@ class UniqueEntityValidator extends ConstraintValidator
         }
 
         array_walk($identifiers, function (&$id, $field) {
-            if (!is_object($id) || $id instanceof \DateTimeInterface) {
+            if (!\is_object($id) || $id instanceof \DateTimeInterface) {
                 $idAsString = $this->formatValue($id, self::PRETTY_DATE);
             } else {
-                $idAsString = sprintf('object("%s")', get_class($id));
+                $idAsString = sprintf('object("%s")', \get_class($id));
             }
 
             $id = sprintf('%s => %s', $field, $idAsString);
