@@ -164,7 +164,7 @@ class PropertyAccessor implements PropertyAccessorInterface
         );
         $propertyValues = $this->readPropertiesUntil($zval, $propertyPath, $propertyPath->getLength(), $this->ignoreInvalidIndices);
 
-        return $propertyValues[count($propertyValues) - 1][self::VALUE];
+        return $propertyValues[\count($propertyValues) - 1][self::VALUE];
     }
 
     /**
@@ -186,7 +186,7 @@ class PropertyAccessor implements PropertyAccessorInterface
                 self::$previousErrorHandler = set_error_handler(self::$errorHandler);
             }
 
-            for ($i = count($propertyValues) - 1; 0 <= $i; --$i) {
+            for ($i = \count($propertyValues) - 1; 0 <= $i; --$i) {
                 $zval = $propertyValues[$i];
                 unset($propertyValues[$i]);
 
@@ -222,7 +222,7 @@ class PropertyAccessor implements PropertyAccessorInterface
                     // if current element's reference chain is not broken - current element
                     // as well as all its ancients in the property path are all passed by reference,
                     // then there is no need to continue the value setting process
-                    if (is_object($zval[self::VALUE]) || isset($zval[self::IS_REF_CHAINED])) {
+                    if (\is_object($zval[self::VALUE]) || isset($zval[self::IS_REF_CHAINED])) {
                         break;
                     }
                 }
@@ -251,16 +251,16 @@ class PropertyAccessor implements PropertyAccessorInterface
             self::throwInvalidArgumentException($message, debug_backtrace(false), 1);
         }
 
-        return null !== self::$previousErrorHandler && false !== call_user_func(self::$previousErrorHandler, $type, $message, $file, $line, $context);
+        return null !== self::$previousErrorHandler && false !== \call_user_func(self::$previousErrorHandler, $type, $message, $file, $line, $context);
     }
 
     private static function throwInvalidArgumentException($message, $trace, $i)
     {
         if (isset($trace[$i]['file']) && __FILE__ === $trace[$i]['file'] && isset($trace[$i]['args'][0])) {
             $pos = strpos($message, $delim = 'must be of the type ') ?: (strpos($message, $delim = 'must be an instance of ') ?: strpos($message, $delim = 'must implement interface '));
-            $pos += strlen($delim);
+            $pos += \strlen($delim);
             $type = $trace[$i]['args'][0];
-            $type = is_object($type) ? get_class($type) : gettype($type);
+            $type = \is_object($type) ? \get_class($type) : \gettype($type);
 
             throw new InvalidArgumentException(sprintf('Expected argument of type "%s", "%s" given', substr($message, $pos, strpos($message, ',', $pos) - $pos), $type));
         }
@@ -302,12 +302,12 @@ class PropertyAccessor implements PropertyAccessorInterface
             );
             $propertyValues = $this->readPropertiesUntil($zval, $propertyPath, $propertyPath->getLength() - 1);
 
-            for ($i = count($propertyValues) - 1; 0 <= $i; --$i) {
+            for ($i = \count($propertyValues) - 1; 0 <= $i; --$i) {
                 $zval = $propertyValues[$i];
                 unset($propertyValues[$i]);
 
                 if ($propertyPath->isIndex($i)) {
-                    if (!$zval[self::VALUE] instanceof \ArrayAccess && !is_array($zval[self::VALUE])) {
+                    if (!$zval[self::VALUE] instanceof \ArrayAccess && !\is_array($zval[self::VALUE])) {
                         return false;
                     }
                 } else {
@@ -316,7 +316,7 @@ class PropertyAccessor implements PropertyAccessorInterface
                     }
                 }
 
-                if (is_object($zval[self::VALUE])) {
+                if (\is_object($zval[self::VALUE])) {
                     return true;
                 }
             }
@@ -344,7 +344,7 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function readPropertiesUntil($zval, PropertyPathInterface $propertyPath, $lastIndex, $ignoreInvalidIndices = true)
     {
-        if (!is_object($zval[self::VALUE]) && !is_array($zval[self::VALUE])) {
+        if (!\is_object($zval[self::VALUE]) && !\is_array($zval[self::VALUE])) {
             throw new UnexpectedTypeException($zval[self::VALUE], $propertyPath, 0);
         }
 
@@ -358,10 +358,10 @@ class PropertyAccessor implements PropertyAccessorInterface
             if ($isIndex) {
                 // Create missing nested arrays on demand
                 if (($zval[self::VALUE] instanceof \ArrayAccess && !$zval[self::VALUE]->offsetExists($property)) ||
-                    (is_array($zval[self::VALUE]) && !isset($zval[self::VALUE][$property]) && !array_key_exists($property, $zval[self::VALUE]))
+                    (\is_array($zval[self::VALUE]) && !isset($zval[self::VALUE][$property]) && !array_key_exists($property, $zval[self::VALUE]))
                 ) {
                     if (!$ignoreInvalidIndices) {
-                        if (!is_array($zval[self::VALUE])) {
+                        if (!\is_array($zval[self::VALUE])) {
                             if (!$zval[self::VALUE] instanceof \Traversable) {
                                 throw new NoSuchIndexException(sprintf(
                                     'Cannot read index "%s" while trying to traverse path "%s".',
@@ -397,7 +397,7 @@ class PropertyAccessor implements PropertyAccessorInterface
             }
 
             // the final value of the path must not be validated
-            if ($i + 1 < $propertyPath->getLength() && !is_object($zval[self::VALUE]) && !is_array($zval[self::VALUE])) {
+            if ($i + 1 < $propertyPath->getLength() && !\is_object($zval[self::VALUE]) && !\is_array($zval[self::VALUE])) {
                 throw new UnexpectedTypeException($zval[self::VALUE], $propertyPath, $i + 1);
             }
 
@@ -428,8 +428,8 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function readIndex($zval, $index)
     {
-        if (!$zval[self::VALUE] instanceof \ArrayAccess && !is_array($zval[self::VALUE])) {
-            throw new NoSuchIndexException(sprintf('Cannot read index "%s" from object of type "%s" because it doesn\'t implement \ArrayAccess.', $index, get_class($zval[self::VALUE])));
+        if (!$zval[self::VALUE] instanceof \ArrayAccess && !\is_array($zval[self::VALUE])) {
+            throw new NoSuchIndexException(sprintf('Cannot read index "%s" from object of type "%s" because it doesn\'t implement \ArrayAccess.', $index, \get_class($zval[self::VALUE])));
         }
 
         $result = self::$resultProto;
@@ -439,9 +439,9 @@ class PropertyAccessor implements PropertyAccessorInterface
 
             if (!isset($zval[self::REF])) {
                 // Save creating references when doing read-only lookups
-            } elseif (is_array($zval[self::VALUE])) {
+            } elseif (\is_array($zval[self::VALUE])) {
                 $result[self::REF] = &$zval[self::REF][$index];
-            } elseif (is_object($result[self::VALUE])) {
+            } elseif (\is_object($result[self::VALUE])) {
                 $result[self::REF] = $result[self::VALUE];
             }
         }
@@ -461,13 +461,13 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function readProperty($zval, $property)
     {
-        if (!is_object($zval[self::VALUE])) {
+        if (!\is_object($zval[self::VALUE])) {
             throw new NoSuchPropertyException(sprintf('Cannot read property "%s" from an array. Maybe you intended to write the property path as "[%1$s]" instead.', $property));
         }
 
         $result = self::$resultProto;
         $object = $zval[self::VALUE];
-        $access = $this->getReadAccessInfo(get_class($object), $property);
+        $access = $this->getReadAccessInfo(\get_class($object), $property);
 
         if (self::ACCESS_TYPE_METHOD === $access[self::ACCESS_TYPE]) {
             $result[self::VALUE] = $object->{$access[self::ACCESS_NAME]}();
@@ -496,7 +496,7 @@ class PropertyAccessor implements PropertyAccessorInterface
         }
 
         // Objects are always passed around by reference
-        if (isset($zval[self::REF]) && is_object($result[self::VALUE])) {
+        if (isset($zval[self::REF]) && \is_object($result[self::VALUE])) {
             $result[self::REF] = $result[self::VALUE];
         }
 
@@ -594,8 +594,8 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function writeIndex($zval, $index, $value)
     {
-        if (!$zval[self::VALUE] instanceof \ArrayAccess && !is_array($zval[self::VALUE])) {
-            throw new NoSuchIndexException(sprintf('Cannot modify index "%s" in object of type "%s" because it doesn\'t implement \ArrayAccess', $index, get_class($zval[self::VALUE])));
+        if (!$zval[self::VALUE] instanceof \ArrayAccess && !\is_array($zval[self::VALUE])) {
+            throw new NoSuchIndexException(sprintf('Cannot modify index "%s" in object of type "%s" because it doesn\'t implement \ArrayAccess', $index, \get_class($zval[self::VALUE])));
         }
 
         $zval[self::REF][$index] = $value;
@@ -612,12 +612,12 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function writeProperty($zval, $property, $value)
     {
-        if (!is_object($zval[self::VALUE])) {
+        if (!\is_object($zval[self::VALUE])) {
             throw new NoSuchPropertyException(sprintf('Cannot write property "%s" to an array. Maybe you should write the property path as "[%1$s]" instead?', $property));
         }
 
         $object = $zval[self::VALUE];
-        $access = $this->getWriteAccessInfo(get_class($object), $property, $value);
+        $access = $this->getWriteAccessInfo(\get_class($object), $property, $value);
 
         if (self::ACCESS_TYPE_METHOD === $access[self::ACCESS_TYPE]) {
             $object->{$access[self::ACCESS_NAME]}($value);
@@ -636,7 +636,7 @@ class PropertyAccessor implements PropertyAccessorInterface
         } elseif (self::ACCESS_TYPE_MAGIC === $access[self::ACCESS_TYPE]) {
             $object->{$access[self::ACCESS_NAME]}($value);
         } elseif (self::ACCESS_TYPE_NOT_FOUND === $access[self::ACCESS_TYPE]) {
-            throw new NoSuchPropertyException(sprintf('Could not determine access type for property "%s" in class "%s".', $property, get_class($object)));
+            throw new NoSuchPropertyException(sprintf('Could not determine access type for property "%s" in class "%s".', $property, \get_class($object)));
         } else {
             throw new NoSuchPropertyException($access[self::ACCESS_NAME]);
         }
@@ -660,12 +660,12 @@ class PropertyAccessor implements PropertyAccessorInterface
         if ($previousValue instanceof \Traversable) {
             $previousValue = iterator_to_array($previousValue);
         }
-        if ($previousValue && is_array($previousValue)) {
-            if (is_object($collection)) {
+        if ($previousValue && \is_array($previousValue)) {
+            if (\is_object($collection)) {
                 $collection = iterator_to_array($collection);
             }
             foreach ($previousValue as $key => $item) {
-                if (!in_array($item, $collection, true)) {
+                if (!\in_array($item, $collection, true)) {
                     unset($previousValue[$key]);
                     $zval[self::VALUE]->{$removeMethod}($item);
                 }
@@ -675,7 +675,7 @@ class PropertyAccessor implements PropertyAccessorInterface
         }
 
         foreach ($collection as $item) {
-            if (!$previousValue || !in_array($item, $previousValue, true)) {
+            if (!$previousValue || !\in_array($item, $previousValue, true)) {
                 $zval[self::VALUE]->{$addMethod}($item);
             }
         }
@@ -712,7 +712,7 @@ class PropertyAccessor implements PropertyAccessorInterface
         $camelized = $this->camelize($property);
         $singulars = (array) Inflector::singularize($camelized);
 
-        if (is_array($value) || $value instanceof \Traversable) {
+        if (\is_array($value) || $value instanceof \Traversable) {
             $methods = $this->findAdderAndRemover($reflClass, $singulars);
 
             if (null !== $methods) {
@@ -751,7 +751,7 @@ class PropertyAccessor implements PropertyAccessorInterface
                     $property,
                     $reflClass->name,
                     implode('()", "', $methods),
-                    is_object($value) ? get_class($value) : gettype($value)
+                    \is_object($value) ? \get_class($value) : \gettype($value)
                 );
             } else {
                 $access[self::ACCESS_TYPE] = self::ACCESS_TYPE_NOT_FOUND;
@@ -786,11 +786,11 @@ class PropertyAccessor implements PropertyAccessorInterface
      */
     private function isPropertyWritable($object, $property)
     {
-        if (!is_object($object)) {
+        if (!\is_object($object)) {
             return false;
         }
 
-        $access = $this->getWriteAccessInfo(get_class($object), $property, array());
+        $access = $this->getWriteAccessInfo(\get_class($object), $property, array());
 
         return self::ACCESS_TYPE_METHOD === $access[self::ACCESS_TYPE]
             || self::ACCESS_TYPE_PROPERTY === $access[self::ACCESS_TYPE]
